@@ -25,7 +25,7 @@ use toml::value::Value as TValue;
 
 use common::cliutil;
 use common::util::{get_belowrc_dump_section_key, get_belowrc_filename, timestamp_to_datetime};
-use model::{Field, FieldId, Queriable};
+use model::{EnumIter, Field, FieldId, Queriable};
 
 use store::advance::{new_advance_local, new_advance_remote};
 use store::Advance;
@@ -89,7 +89,7 @@ pub enum DumpField<F: FieldId> {
     FieldId(F),
 }
 
-pub type CgroupField = DumpField<model::CgroupModelFieldId>;
+pub type CgroupField = DumpField<model::SingleCgroupModelFieldId>;
 pub type ProcessField = DumpField<model::SingleProcessModelFieldId>;
 pub type SystemField = DumpField<model::SystemModelFieldId>;
 pub type DiskField = DumpField<model::SingleDiskModelFieldId>;
